@@ -10,9 +10,8 @@ import re
 import sys
 import tempfile
 import warnings
-from asyncio import StreamReader
 from dataclasses import field, make_dataclass
-from datetime import datetime, timedelta
+from datetime import timedelta
 from enum import EnumMeta
 from keyword import iskeyword
 from numbers import Number
@@ -84,16 +83,15 @@ class CLIInstance(Instance):
     def branch(self) -> Iterator[Instance]:  # TODO: Self reference
         child = self.__class__(self._solver)
         child._parent = self
+
         # Copy current information from analysis
         child._method = self.method
         child.output_type = self.output_type
         child._output = self._output
         child._input = self.input
-        try:
-            with self._lock:
-                yield child
-        finally:
-            del child
+
+        with self._lock:
+            yield child
 
     @property
     def method(self) -> Method:
@@ -157,6 +155,7 @@ class CLIInstance(Instance):
             yield files
         finally:
             for file in gen_files:
+                file.close()
                 os.remove(file.name)
 
     @property
@@ -265,9 +264,8 @@ class CLIInstance(Instance):
             "--output-time",
             "--output-objective",
             "--output-output-item",
+            "--statistics",  # Enable statistics
         ]
-        # Enable statistics
-        cmd.append("-s")
 
         # Process number of solutions to be generated
         if all_solutions:
@@ -282,7 +280,7 @@ class CLIInstance(Instance):
                 )
             if "-a" not in self._solver.stdFlags:
                 raise NotImplementedError("Solver does not support the -a flag")
-            cmd.append("-a")
+            cmd.append("--all-solutions")
         elif nr_solutions is not None:
             if nr_solutions <= 0:
                 raise ValueError(
@@ -295,26 +293,26 @@ class CLIInstance(Instance):
                 )
             if "-n" not in self._solver.stdFlags:
                 raise NotImplementedError("Solver does not support the -n flag")
-            cmd.extend(["-n", str(nr_solutions)])
-        if "-a" in self._solver.stdFlags and self.method != Method.SATISFY:
-            cmd.append("-a")
+            cmd.extend(["--num-solutions", str(nr_solutions)])
+        if "-i" in self._solver.stdFlags or "-a" in self._solver.stdFlags:
+            cmd.append("--intermediate-solutions")
         # Set number of processes to be used
         if processes is not None:
             if "-p" not in self._solver.stdFlags:
                 raise NotImplementedError("Solver does not support the -p flag")
-            cmd.extend(["-p", str(processes)])
+            cmd.extend(["--parallel", str(processes)])
         # Set random seed to be used
         if random_seed is not None:
             if "-r" not in self._solver.stdFlags:
                 raise NotImplementedError("Solver does not support the -r flag")
-            cmd.extend(["-r", str(random_seed)])
+            cmd.extend(["--random-seed", str(random_seed)])
         # Enable free search if specified
         if free_search:
             if "-f" not in self._solver.stdFlags:
                 raise NotImplementedError("Solver does not support the -f flag")
-            cmd.append("-f")
+            cmd.append("--free-search")
         # Set compiler optimisation level if specified
-        if optimisation_level:
+        if optimisation_level is not None:
             cmd.extend(["-O", str(optimisation_level)])
 
         # Set time limit for the MiniZinc solving
@@ -322,7 +320,7 @@ class CLIInstance(Instance):
             cmd.extend(["--time-limit", str(int(timeout.total_seconds() * 1000))])
 
         if verbose:
-            cmd.append("-v")
+            cmd.append("--verbose")
 
         for flag, value in kwargs.items():
             if not flag.startswith("-"):
@@ -333,14 +331,16 @@ class CLIInstance(Instance):
             else:
                 cmd.extend([flag, value])
 
+        self.method  # Ensure self.analyse() is executed
+
         # Add files as last arguments
         with self.files() as files, self._solver.configuration() as solver:
             assert self.output_type is not None
             cmd.extend(files)
             # Run the MiniZinc process
             proc = await self._driver.create_process(cmd, solver=solver)
-            assert isinstance(proc.stderr, StreamReader)
-            assert isinstance(proc.stdout, StreamReader)
+            assert isinstance(proc.stderr, asyncio.StreamReader)
+            assert isinstance(proc.stdout, asyncio.StreamReader)
 
             # Python 3.7+: replace with asyncio.create_task
             read_stderr = asyncio.ensure_future(_read_all(proc.stderr))
@@ -350,7 +350,7 @@ class CLIInstance(Instance):
 
             remainder: bytes = b""
             try:
-                async for raw_sol in _seperate_solutions(proc.stdout, timeout):
+                async for raw_sol in _seperate_solutions(proc.stdout):
                     status = Status.SATISFIED
                     solution, statistics = parse_solution(
                         raw_sol, self.output_type, self._enum_map
@@ -363,9 +363,8 @@ class CLIInstance(Instance):
                 # Read remaining text in buffer
                 code = await proc.wait()
                 remainder = err.partial
-            except (asyncio.TimeoutError, asyncio.CancelledError) as e:
-                # Process was reached hard deadline (timeout + 1 sec) or was
-                # cancelled by the user.
+            except asyncio.CancelledError as e:
+                # Process was cancelled by the user.
                 # Terminate process and read remaining output
                 proc.terminate()
                 remainder = await _read_all(proc.stdout)
@@ -392,47 +391,6 @@ class CLIInstance(Instance):
                         stderr = await read_stderr
                     debug_output.write_bytes(stderr)
 
-    async def solve_async(
-        self,
-        timeout: Optional[timedelta] = None,
-        nr_solutions: Optional[int] = None,
-        processes: Optional[int] = None,
-        random_seed: Optional[int] = None,
-        all_solutions=False,
-        intermediate_solutions=False,
-        free_search: bool = False,
-        optimisation_level: Optional[int] = None,
-        **kwargs,
-    ):
-        status = Status.UNKNOWN
-        solution = None
-        statistics: Dict[str, Any] = {}
-
-        multiple_solutions = (
-            all_solutions or intermediate_solutions or nr_solutions is not None
-        )
-        if multiple_solutions:
-            solution = []
-
-        async for result in self.solutions(
-            timeout=timeout,
-            nr_solutions=nr_solutions,
-            processes=processes,
-            random_seed=random_seed,
-            all_solutions=all_solutions,
-            free_search=free_search,
-            optimisation_level=optimisation_level,
-            **kwargs,
-        ):
-            status = result.status
-            statistics.update(result.statistics)
-            if result.solution is not None:
-                if multiple_solutions:
-                    solution.append(result.solution)
-                else:
-                    solution = result.solution
-        return Result(status, solution, statistics)
-
     @contextlib.contextmanager
     def flat(
         self,
@@ -474,8 +432,11 @@ class CLIInstance(Instance):
         cmd.extend(["--ozn", ozn.name])
         ozn.close()
 
+        if timeout is not None:
+            cmd.extend(["--time-limit", str(int(timeout.total_seconds() * 1000))])
+
         # Set compiler optimisation level if specified
-        if optimisation_level:
+        if optimisation_level is not None:
             cmd.extend(["-O", str(optimisation_level)])
 
         for flag, value in kwargs.items():
@@ -491,7 +452,7 @@ class CLIInstance(Instance):
         with self.files() as files:
             cmd.extend(files)
             # Run the MiniZinc process
-            output = self._driver.run(cmd, solver=self._solver, timeout=timeout)
+            output = self._driver.run(cmd, solver=self._solver)
 
         statistics: Dict[str, Any] = {}
         matches = re.findall(rb"%%%mzn-stat:? (\w*)=([^\r\n]*)", output.stdout)
@@ -513,27 +474,18 @@ class CLIInstance(Instance):
         return super().add_string(code)
 
 
-async def _seperate_solutions(stream: StreamReader, timeout: Optional[timedelta]):
-    deadline = None
-    if timeout is not None:
-        deadline = datetime.now() + timeout + timedelta(seconds=1)
+async def _seperate_solutions(stream: asyncio.StreamReader):
     solution: bytes = b""
     while not stream.at_eof():
         try:
-            if deadline is None:
-                solution += await stream.readuntil(SEPARATOR)
-            else:
-                t = deadline - datetime.now()
-                solution += await asyncio.wait_for(
-                    stream.readuntil(SEPARATOR), t.total_seconds()
-                )
+            solution += await stream.readuntil(SEPARATOR)
             yield solution
             solution = b""
         except asyncio.LimitOverrunError as err:
             solution += await stream.readexactly(err.consumed)
 
 
-async def _read_all(stream: StreamReader):
+async def _read_all(stream: asyncio.StreamReader):
     output: bytes = b""
     while not stream.at_eof():
         try:
