@@ -12,9 +12,6 @@ from typing import List, Optional, Type
 
 from minizinc.instance import Instance
 
-#: MiniZinc version required by the python package
-required_version = (2, 3, 2)
-
 
 class Driver(ABC):
     """The abstract representation of a MiniZinc driver within MiniZinc Python."""
@@ -37,7 +34,7 @@ class Driver(ABC):
             ConfigurationError: If an the driver version is found to be
                 incompatible with MiniZinc Python
         """
-        self.check_version()
+        pass
 
     @property
     @abstractmethod
@@ -65,6 +62,25 @@ class Driver(ABC):
         """
         pass
 
+    @abstractmethod
+    def available_solvers(self, refresh=False):
+        """Returns a list of available solvers
+
+        This method returns the list of solvers available to the Driver object
+        according to the current environment. Note that the list of solvers might
+        be cached for future usage. The refresh argument can be used to ignore
+        the current cache.
+
+        Args:
+            refresh (bool): When set to true, the Driver will rediscover the
+                available solvers from the current environment.
+
+        Returns:
+            Dict[str, List[Solver]]: A dictionary that maps solver tags to MiniZinc
+                solver configurations that can be used with the Driver object.
+        """
+        pass
+
 
 def find_driver(
     path: Optional[List[str]] = None, name: str = "minizinc"
