@@ -6,9 +6,10 @@ import contextlib
 import sys
 from abc import ABC, abstractmethod
 from datetime import timedelta
-from typing import Optional
+from typing import Any, AsyncIterator, Dict, Optional
 
 from .model import Method, Model
+from .result import Result, Status
 from .solver import Solver
 
 
@@ -45,7 +46,7 @@ class Instance(Model, ABC):
         free_search: bool = False,
         optimisation_level: Optional[int] = None,
         **kwargs,
-    ):
+    ) -> Result:
         """Solves the Instance using its given solver configuration.
 
         Find the solutions to the given MiniZinc instance using the given solver
@@ -128,7 +129,6 @@ class Instance(Model, ABC):
                 asyncio.events.set_event_loop(None)
                 loop.close()
 
-    @abstractmethod
     async def solve_async(
         self,
         timeout: Optional[timedelta] = None,
@@ -140,7 +140,7 @@ class Instance(Model, ABC):
         free_search: bool = False,
         optimisation_level: Optional[int] = None,
         **kwargs,
-    ):
+    ) -> Result:
         """Solves the Instance using its given solver configuration in a coroutine.
 
         This method returns a coroutine that finds solutions to the given
@@ -157,10 +157,37 @@ class Instance(Model, ABC):
                 model instance.
 
         """
-        pass
+        status = Status.UNKNOWN
+        solution = None
+        statistics: Dict[str, Any] = {}
+
+        multiple_solutions = (
+            all_solutions or intermediate_solutions or nr_solutions is not None
+        )
+        if multiple_solutions:
+            solution = []
+
+        async for result in self.solutions(
+            timeout=timeout,
+            nr_solutions=nr_solutions,
+            processes=processes,
+            random_seed=random_seed,
+            all_solutions=all_solutions,
+            free_search=free_search,
+            optimisation_level=optimisation_level,
+            **kwargs,
+        ):
+            status = result.status
+            statistics.update(result.statistics)
+            if result.solution is not None:
+                if multiple_solutions:
+                    solution.append(result.solution)
+                else:
+                    solution = result.solution
+        return Result(status, solution, statistics)
 
     @abstractmethod
-    async def solutions(
+    def solutions(
         self,
         timeout: Optional[timedelta] = None,
         nr_solutions: Optional[int] = None,
@@ -171,7 +198,7 @@ class Instance(Model, ABC):
         free_search: bool = False,
         optimisation_level: Optional[int] = None,
         **kwargs,
-    ):
+    ) -> AsyncIterator[Result]:
         """An asynchronous generator for solutions of the MiniZinc instance.
 
         This method provides an asynchronous generator for the solutions of the
@@ -182,9 +209,9 @@ class Instance(Model, ABC):
         arguments, see the documentation of :func:`~MiniZinc.Instance.solve`.
 
         Yields:
-            Tuple[Status, Optional[Dict], Dict]:
-                tuple containing solving status, values assigned, and
-                statistical information.
+            Result:
+                A Result object containing the current solving status, values
+                assigned, and statistical information.
 
         """
         pass
