@@ -5,6 +5,11 @@
 from enum import Enum
 from json import JSONDecoder, JSONEncoder
 
+try:
+    import numpy
+except ImportError:
+    numpy = None
+
 
 class MZNJSONEncoder(JSONEncoder):
     def default(self, o):
@@ -12,7 +17,11 @@ class MZNJSONEncoder(JSONEncoder):
             return {"e": o.name}
         if isinstance(o, set) or isinstance(o, range):
             return {"set": [{"e": i.name} if isinstance(i, Enum) else i for i in o]}
-
+        if numpy is not None:
+            if isinstance(o, numpy.ndarray):
+                return o.tolist()
+            if isinstance(o, numpy.generic):
+                return o.item()
         return super().default(o)
 
 
@@ -22,9 +31,9 @@ class MZNJSONDecoder(JSONDecoder):
             self.enum_map = {}
         else:
             self.enum_map = enum_map
-        JSONDecoder.__init__(self, object_hook=self.object_hook, *args, **kwargs)
+        JSONDecoder.__init__(self, object_hook=self.mzn_object_hook, *args, **kwargs)
 
-    def object_hook(self, obj):
+    def mzn_object_hook(self, obj):
         if len(obj) == 1 and "set" in obj:
             if len(obj["set"]) == 1 and isinstance(obj["set"][0], list):
                 assert len(obj["set"][0]) == 2
